<template>
  <section
    :class="{ ['color' + snack.shop_color]: true, ['layout' + snack.shop_style]: true }"
    class="snack"
  >
    <div
      v-show="snack.shop_style == 1 || snack.shop_style == 2"
      class="shop-html">
      <div class="shop-body">
        <div class="headerwidthcontainer">
          <div
            v-if="snack.admin"
            id="menu">
            <ul
              id="nav"
              class="tab-buttons">
              <router-link
                :to="{name: 'snack_shopmain'}"
                tag="li">
                <a
                  :class="{selected: (this.$route.name === 'snack_shopmain')}"
                  class="tab"
                >Main Page</a>
              </router-link>
              <router-link
                :to="{name: 'snack_shopaccounting'}"
                tag="li">
                <a
                  :class="{selected: (this.$route.name === 'snack_shopaccounting')}"
                  class="tab">Accounting</a>
              </router-link>
              <div class="clear"/>
            </ul>
          </div>
          <div id="shopname">{{ snack.name }}</div>
          <div
            v-show="snack.shop_style == 1"
            id="shelf">
            <img
              id="shelfimg"
              src="/images/shop/snackshop/shelf.png">
          </div>
          <div id="featureditem">
            <h1>Featured Item</h1>
            <div
              v-for="item in inventory"
              v-show="item.active"
              :key="item.id"
              :id="item.canonicalName"
              class="item active"
            >
              <p>{{ item.prettyName }}</p>
            </div>
          </div>
          <div id="yatlogo">
            <img
              id="yatlogoimg"
              :src="logo"
              width="98"
              height="81">
          </div>
          <div
            v-if="snack.shop_style == 1"
            id="banner">
            <img
              id="snackshopwindow"
              src="/images/shop/snackshop/window.png">
          </div>
          <div
            v-else
            id="banner">
            <img
              id="snackshopwindow"
              src="/images/shop/snackshop/oval.png">
          </div>
        </div>
        <div class="contentwidthcontainer">
          <div id="sidebar">
            <div
              id="featureditemselect"
              class="featured">
              <h2>Featured Item</h2>
              <div
                v-for="item in inventory"
                :key="item.id">
                <p>
                  <a
                    :id="item.canonicalName"
                    :class="{checked: (item.active)}"
                    class="item"
                    @click="toggleFeaturedItem"
                  >{{ item.prettyName }}</a>
                </p>
              </div>
            </div>
            <action-buttons
              v-if="Object.keys(snack).length"
              :has-swiper="hasSwiper"
              :shop="snack"/>
          </div>
          <div
            id="maincontent"
            class="tabs">
            <router-view
              :shop="snack"
              class="tab selected"
              @simple-one="simpleOne"
              @simple-two="simpleTwo"
              @busy-one="busyOne"
              @busy-two="busyTwo"
            />
          </div>
        </div>
      </div>
    </div>
  </section>
</template>

<script>
import ShopBaseView from "../shopBase.js";
import Headlines from "../Headlines.vue";
import ActionButtons from "../ActionButtons.vue";

export default {
  components: {
    Headlines,
    ActionButtons
  },
  extends: ShopBaseView,
  data() {
    return {
      logo: app.network.data.shop_logo,
      snack: {},
      hasSwiper: app.computerSettings.swiper,
      inventory: ""
    };
  },
  created: function() {
    this.getData();
    this.snackInventory();
  },
  methods: {
    getData() {
      app.session.SetSession().then(() => {
        app.api
          .Get("/snack_shop/" + app.session.data.id)
          .then(Response => {
            this.snack = Response;
            this.$router.push({ name: "snack_shopmain" });
            app.Message("Successfully loaded the Snack Shop!", "success");
          })
          .catch(x => app.Message(x.error, "error"));
      });
    },
    simpleOne() {
      this.snack.shop_style = 1;
      this.snack.shop_color = 1;
    },
    simpleTwo() {
      this.snack.shop_style = 1;
      this.snack.shop_color = 2;
    },
    busyOne() {
      this.snack.shop_style = 2;
      this.snack.shop_color = 1;
    },
    busyTwo() {
      this.snack.shop_style = 2;
      this.snack.shop_color = 2;
    },
    toggleFeaturedItem() {
      console.log("clicked");
      this.inventory[0].active = !this.inventory[0].active;
      this.inventory[1].active = !this.inventory[1].active;
    },
    snackInventory() {
      if (app.network.data.snack_shop_items == "1") {
        return (this.inventory = [
          {
            id: 1,
            canonicalName: "freeze-pop",
            prettyName: "Freeze Pop",
            active: true
          }
        ]);
      } else {
        return (this.inventory = [
          {
            id: 1,
            canonicalName: "freeze-pop",
            prettyName: "Freeze Pop",
            active: false
          },
          {
            id: 2,
            canonicalName: "ice-cream",
            prettyName: "Ice Cream Sandwich",
            active: true
          }
        ]);
      }
    }
  },
};
</script>

<style lang="less">
@import "../../shared.less";
</style>


<style lang="less">
.snack.layout1.color1 {
  /* snackshop common */
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat: right;
  @bgcolor: #00353d;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;
  // snackshop color 1
  @topnavcolor: rgba(0, 0, 0, 0.3);
  @shoptitlecolor: #ed8488;
  @logoborder: 0.5rem solid #bc2f33;
  // if this is white you can't see it
  @shopdesccolor: #fff;
  // @shopdesccolor: #ed8488;
  @homemsgcolor: #144a68;
  @activetabcolor: #dbaf34;
  @navbgcolor: #fccb42;
  @activetabcolor: #dbaf34;
  @tabfontcolor: #ed8488;
  @maincontentp: #3f662f;
  @maincontenth1: #85171a;
  @h1shadow: none;
  @activetabcolor: #fff;
  @buttonbackground: #7eac0e;
  @buttonborder: #a3cf69;
  @buttonhoverbg: #69900a;
  @buttonborderhover: #a3cf69;
  @factsbg: rgba(255, 255, 255, 0.5);
  @factsh2: #3f662f;
  @factstitlebg: rgba(255, 255, 255, 0.3);
  @factslistcolor: rgba(255, 255, 255, 0.6);
  @factscolor: #2f4c23;
  @hometxtcolor: #008e18;
  @shopbackgroundcolor: #fccb42;
  @hometxtcolor: #008e18;
  @bannerfontcolor: #ffffff;
  @shopbackgroundcolor: #fccb42;
  @featureditemcolor: #d6f78d;
  @bgcontentimage: url(/images/shop/snackshop/snackshopbottombg1.jpg);
  @bgimage: url(/images/shop/snackshop/snackshopbg1.jpg);
  @salestext: #85171a;
  @salesborder: 1rem solid #784d43;

  @import "./snackLayout1.less";
}
</style>

<style lang="less">
.snack.layout1.color2 {
  /* snackshop common */
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat: right;
  @bgcolor: #00353d;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;
  // snackshop color 2
  @topnavcolor: rgba(0, 0, 0, 0.3);
  @shoptitlecolor: #ed8488;
  @logoborder: 0.5rem solid #bc2f33;
  // if this is white you can't see it
  @shopdesccolor: #fff;
  // @shopdesccolor: #ed8488;
  @homemsgcolor: #144a68;
  @activetabcolor: #dbaf34;
  @navbgcolor: #fccb42;
  @activetabcolor: #dbaf34;
  @tabfontcolor: #ed8488;
  @maincontentp: #3f662f;
  @maincontenth1: #85171a;
  @h1shadow: none;
  @activetabcolor: #fff;
  @buttonbackground: #7eac0e;
  @buttonborder: #a3cf69;
  @buttonhoverbg: #69900a;
  @buttonborderhover: #a3cf69;
  @factsbg: rgba(255, 255, 255, 0.5);
  @factsh2: #3f662f;
  @factstitlebg: rgba(255, 255, 255, 0.3);
  @factslistcolor: rgba(255, 255, 255, 0.6);
  @factscolor: #2f4c23;
  @hometxtcolor: #008e18;
  @shopbackgroundcolor: #fccb42;
  @hometxtcolor: #008e18;
  @bannerfontcolor: #ffffff;
  @shopbackgroundcolor: #fccb42;
  @featureditemcolor: #d6f78d;
  @bgcontentimage: url(/images/shop/snackshop/snackshopbottombg2.jpg);
  @bgimage: url(/images/shop/snackshop/snackshopbg2.jpg);
  @salestext: #85171a;
  @salesborder: 1rem solid #784d43;

  @import "./snackLayout1.less";
}
</style>

<style lang="less">
.snack.layout2.color1 {
  /* snackshop common */
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat: right;
  @bgcolor: #00353d;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;
  // snackshop color 1
  @topnavcolor: rgba(0, 0, 0, 0.3);
  @shoptitlecolor: #ed8488;
  @logoborder: 0.5rem solid #bc2f33;
  @shopdesccolor: #85171a;
  @homemsgcolor: #144a68;
  @activetabcolor: #dbaf34;
  @navbgcolor: #fccb42;
  @activetabcolor: #dbaf34;
  @tabfontcolor: #ed8488;
  @maincontentp: #3f662f;
  @maincontenth1: #85171a;
  @h1shadow: none;
  @activetabcolor: #fff;
  @buttonbackground: #7eac0e;
  @buttonborder: #a3cf69;
  @buttonhoverbg: #69900a;
  @buttonborderhover: #a3cf69;
  @factsbg: rgba(255, 255, 255, 0.5);
  @factsh2: #3f662f;
  @factstitlebg: rgba(255, 255, 255, 0.3);
  @factslistcolor: rgba(255, 255, 255, 0.6);
  @factscolor: #2f4c23;
  @hometxtcolor: #008e18;
  @shopbackgroundcolor: #fccb42;
  @hometxtcolor: #008e18;
  @bannerfontcolor: #ffffff;
  @shopbackgroundcolor: #fccb42;
  @featureditemcolor: #d6f78d;
  @bgcontentimage: url(/images/shop/snackshop/snackshopbottombg1.jpg);
  @bgimage: url(/images/shop/snackshop/snackshop2bg1.jpg);
  @salestext: #85171a;
  @salesborder: 1rem solid #784d43;
  @featuredbg: url(/images/shop/snackshop/bg-featured-item-red.png) no-repeat;
  @featuredborder: #85171a;

  @import "./snackLayout2.less";
}
</style>

<style lang="less">
.snack.layout2.color2 {
  /* snackshop common */
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat: right;
  @bgcolor: #00353d;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;
  // snackshop color 2
  @topnavcolor: rgba(0, 0, 0, 0.3);
  @shoptitlecolor: #ed8488;
  @logoborder: 0.5rem solid #004b64;
  @shopdesccolor: #004b64;
  @homemsgcolor: #144a68;
  @activetabcolor: #dbaf34;
  @navbgcolor: #fccb42;
  @activetabcolor: #dbaf34;
  @tabfontcolor: #ed8488;
  @maincontentp: #3f662f;
  @maincontenth1: #004b64;
  @h1shadow: none;
  @activetabcolor: #fff;
  @buttonbackground: #7eac0e;
  @buttonborder: #a3cf69;
  @buttonhoverbg: #69900a;
  @buttonborderhover: #a3cf69;
  @factsbg: rgba(255, 255, 255, 0.5);
  @factsh2: #3f662f;
  @factstitlebg: rgba(255, 255, 255, 0.3);
  @factslistcolor: rgba(255, 255, 255, 0.6);
  @factscolor: #2f4c23;
  @hometxtcolor: #008e18;
  @shopbackgroundcolor: #fccb42;
  @hometxtcolor: #008e18;
  @bannerfontcolor: #ffffff;
  @shopbackgroundcolor: #fccb42;
  @featureditemcolor: #d6f78d;
  @bgcontentimage: url(/images/shop/snackshop/snackshopbottombg2.jpg);
  @bgimage: url(/images/shop/snackshop/snackshop2bg2.jpg);
  @salestext: #004b64;
  @salesborder: 1rem solid #004b64;
  @featuredbg: url(/images/shop/snackshop/bg-featured-item-blue.png) no-repeat;
  @featuredborder: #004b64;

  @import "./snackLayout2.less";
}
</style>


